==> haskell-aeson-better-errors-0.9.1.0-118-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-better-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-better-errors
version: 0.9.1.0
id: aeson-better-errors-0.9.1.0-4eRW6I0MGCf4KpzCjslxtB
key: aeson-better-errors-0.9.1.0-4eRW6I0MGCf4KpzCjslxtB
license: MIT
maintainer: harry@garrood.me
author: Harry Garrood
homepage: https://github.com/hdgarrood/aeson-better-errors
synopsis: Better error messages when decoding JSON values.
description:
    A small package which gives you the tools to build parsers to decode JSON
    values, and gives good error messages when parsing fails.
    See also <http://harry.garrood.me/blog/aeson-better-errors/>.
category: Text, Web, JSON
abi: 7a32066d1991b752d28b0d992de9c21e
exposed: True
exposed-modules:
    Data.Aeson.BetterErrors Data.Aeson.BetterErrors.Internal
hidden-modules: Data.Aeson.BetterErrors.Utils
import-dirs: /usr/lib/ghc-8.6.5/site-local/aeson-better-errors-0.9.1.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/aeson-better-errors-0.9.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/aeson-better-errors-0.9.1.0
hs-libraries: HSaeson-better-errors-0.9.1.0-4eRW6I0MGCf4KpzCjslxtB
depends:
    aeson-1.4.3.0-F9e2BgjvX59JUef9tsq2ab base-4.12.0.0
    bytestring-0.10.8.2 dlist-0.8.0.6-CQRMCGRgL5B3ZxhntX4iOr mtl-2.2.2
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b text-1.2.3.1
    transformers-0.5.6.2
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
    unordered-containers-0.2.10.0-KN3bhnJnJVDChkuCyIQcSr
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    void-0.7.3-3RYOrpJEx0UYkI9Ikv0XI
haddock-interfaces: /usr/share/doc/haskell-aeson-better-errors/html/aeson-better-errors.haddock
haddock-html: /usr/share/doc/haskell-aeson-better-errors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-better-errors-0.9.1.0-123-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-better-errors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-better-errors
version: 0.9.1.0
id: aeson-better-errors-0.9.1.0-4pVSzjuCEwd26shr3TRoCb
key: aeson-better-errors-0.9.1.0-4pVSzjuCEwd26shr3TRoCb
license: MIT
maintainer: harry@garrood.me
author: Harry Garrood
homepage: https://github.com/hdgarrood/aeson-better-errors
synopsis: Better error messages when decoding JSON values.
description:
    A small package which gives you the tools to build parsers to decode JSON
    values, and gives good error messages when parsing fails.
    See also <http://harry.garrood.me/blog/aeson-better-errors/>.
category: Text, Web, JSON
abi: 1cb4d53338671dbb53354d9a39867532
exposed: True
exposed-modules:
    Data.Aeson.BetterErrors Data.Aeson.BetterErrors.Internal
hidden-modules: Data.Aeson.BetterErrors.Utils
import-dirs: /usr/lib/ghc-8.6.5/site-local/aeson-better-errors-0.9.1.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/aeson-better-errors-0.9.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/aeson-better-errors-0.9.1.0
hs-libraries: HSaeson-better-errors-0.9.1.0-4pVSzjuCEwd26shr3TRoCb
depends:
    aeson-1.4.3.0-BTVTAPf4Xo575Po56SJ3Aq base-4.12.0.0
    bytestring-0.10.8.2 dlist-0.8.0.6-8YB2hmqrBvZK0CvUtkBwRY mtl-2.2.2
    scientific-0.3.6.2-L1dtV0bHm4E7J1We1UVw6b text-1.2.3.1
    transformers-0.5.6.2
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
    unordered-containers-0.2.10.0-2N7l4ZvxBr3HGayD0s0P1Q
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    void-0.7.3-3RYOrpJEx0UYkI9Ikv0XI
haddock-interfaces: /usr/share/doc/haskell-aeson-better-errors/html/aeson-better-errors.haddock
haddock-html: /usr/share/doc/haskell-aeson-better-errors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
